@@ -251,6 +251,30 @@
         <source>Announce these services to other systems via Zeroconf</source>
         <translation>Zeroconf-Veröffentlichung</translation>
     </message>
+    <message>
+        <source>Remove %1</source>
+        <translation>%1 entfernen</translation>
+    </message>
+    <message>
+        <source>Remove host?</source>
+        <translation>Rechner entfernen?</translation>
+    </message>
+    <message>
+        <source>Yes</source>
+        <translation>Ja</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation>Nein</translation>
+    </message>
+    <message>
+        <source>No XBMC hosts configured yet.</source>
+        <translation>Kein XBMC Rechner eingerichtet.</translation>
+    </message>
+    <message>
+        <source>After having set up those options, add your XBMC host here.</source>
+        <translation>Nachdem Sie diese Einstellungen vorgenommen haben, fügen Sie den Rechner hier hinzu.</translation>
+    </message>
 </context>
 <context>
     <name>Episodes</name>
@@ -372,6 +396,10 @@
         <source>Add to playlist</source>
         <translation>Zur Playliste</translation>
     </message>
+    <message>
+        <source>Download</source>
+        <translation>Herunterladen</translation>
+    </message>
 </context>
 <context>
     <name>LibraryView</name>
@@ -426,6 +454,10 @@
         <source>Rescan library</source>
         <translation>Bibliothek aktualisieren</translation>
     </message>
+    <message>
+        <source>XBMC on %1</source>
+        <translation>XBMC auf %1</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -477,6 +509,18 @@
         <source>NFC tag is outdated. In order to use it with Xbmcremote you need to update it by rewriting connection information to it.</source>
         <translation>NFC Tag ist veraltet. Um dieses Tag weiterhin mit Xbmcremote zu verwenden, müsses Sie es erneut beschreiben.</translation>
     </message>
+    <message>
+        <source>Tag written successfully. NOTE: This tag does not offer enough space to write all informations. Wake on LAN will not work with this tag.</source>
+        <translation>Tag erfolgreich beschrieben. ACHTUNG: Dieses Tag bietet nicht genug speicherplatz für alle Informationen. Wake on LAN wird damit nicht funktionieren.</translation>
+    </message>
+    <message>
+        <source>Tag written successfully.</source>
+        <translation>Tag erfolgreich beschrieben.</translation>
+    </message>
+    <message>
+        <source>Error writing NFC tag.</source>
+        <translation>Fehler beim Schreiben des NFC Tags.</translation>
+    </message>
 </context>
 <context>
     <name>NoConnectionPage</name>
@@ -485,6 +529,89 @@
         <translation>Verbinden</translation>
     </message>
 </context>
+<context>
+    <name>NowPlayingDetails</name>
+    <message>
+        <source>Rating:</source>
+        <translation>Bewertung:</translation>
+    </message>
+    <message>
+        <source>Season:</source>
+        <translation>Staffel:</translation>
+    </message>
+    <message>
+        <source>Episode:</source>
+        <translation>Folge:</translation>
+    </message>
+    <message>
+        <source>First aired:</source>
+        <translation>Erstausstrahlung:</translation>
+    </message>
+    <message>
+        <source>Genre:</source>
+        <translation>Genre:</translation>
+    </message>
+    <message>
+        <source>Year:</source>
+        <translation>Jahr:</translation>
+    </message>
+    <message>
+        <source>Director:</source>
+        <translation>Direktor:</translation>
+    </message>
+    <message>
+        <source>Tagline:</source>
+        <translation>Titelzeile:</translation>
+    </message>
+    <message>
+        <source>MPAA:</source>
+        <translation>Altersfreigabe:</translation>
+    </message>
+    <message>
+        <source>Instrument:</source>
+        <translation>Instrument:</translation>
+    </message>
+    <message>
+        <source>Style:</source>
+        <translation>Stil:</translation>
+    </message>
+    <message>
+        <source>Mood:</source>
+        <translation>Stimmung:</translation>
+    </message>
+    <message>
+        <source>Born:</source>
+        <translation>Geboren:</translation>
+    </message>
+    <message>
+        <source>Formed:</source>
+        <translation>Formiert:</translation>
+    </message>
+    <message>
+        <source>Died:</source>
+        <translation>Gestorben:</translation>
+    </message>
+    <message>
+        <source>Disbanded:</source>
+        <translation>Auflösung:</translation>
+    </message>
+    <message>
+        <source>Duration:</source>
+        <translation>Dauer:</translation>
+    </message>
+    <message>
+        <source>Comment:</source>
+        <translation>Kommentar:</translation>
+    </message>
+    <message>
+        <source>Playcount:</source>
+        <translation>Zähler:</translation>
+    </message>
+    <message>
+        <source>Cast:</source>
+        <translation>Besetzung:</translation>
+    </message>
+</context>
 <context>
     <name>NowPlayingPage</name>
     <message>
@@ -499,6 +626,10 @@
         <source>Year:</source>
         <translation>Jahr:</translation>
     </message>
+    <message>
+        <source>Episode:</source>
+        <translation>Folge:</translation>
+    </message>
 </context>
 <context>
     <name>NowPlayingView</name>
@@ -521,6 +652,10 @@
         <source>Remove from playlist</source>
         <translation>Aus Abspielliste entfernen</translation>
     </message>
+    <message>
+        <source>Clear playlist</source>
+        <translation>Liste löschen</translation>
+    </message>
 </context>
 <context>
     <name>Seasons</name>
@@ -594,6 +729,14 @@
         <source>Pause music</source>
         <translation>Pausiere Musik</translation>
     </message>
+    <message>
+        <source>Ignore articles for sorting</source>
+        <translation>Artikel für Sortierung ignorieren</translation>
+    </message>
+    <message>
+        <source>Show call notifications</source>
+        <translation>Anrufbenachrichtigung anzeigen</translation>
+    </message>
 </context>
 <context>
     <name>Shares</name>
@@ -617,6 +760,13 @@
         <translation>Lieder</translation>
     </message>
 </context>
+<context>
+    <name>SymbianHelper</name>
+    <message>
+        <source>Incoming call</source>
+        <translation>Eingehender Anruf</translation>
+    </message>
+</context>
 <context>
     <name>TvShows</name>
     <message>
@@ -673,8 +823,19 @@
         <translation>NFC Tag schreiben</translation>
     </message>
     <message>
-        <source>Tag written successfully.</source>
-        <translation>Tag erfolgreich beschrieben.</translation>
+        <source>Write NFC tag</source>
+        <translation>NFC Tag schreiben</translation>
+    </message>
+</context>
+<context>
+    <name>Xbmc</name>
+    <message>
+        <source>Finished downloading %1</source>
+        <translation>Laden von %1 beendet</translation>
+    </message>
+    <message>
+        <source>Error downloading %1</source>
+        <translation>Fehler beim Laden von %1</translation>
     </message>
 </context>
 <context>
@@ -762,5 +923,9 @@
         <source>Flattr</source>
         <translation>Flattr</translation>
     </message>
+    <message>
+        <source>Quit XBMC?</source>
+        <translation>XBMC beenden?</translation>
+    </message>
 </context>
 </TS>
