@@ -5,6 +5,7 @@
 #include <QKeyEvent>
 #ifdef Q_WS_MAEMO_5
 #include <QtDBus/QDBusObjectPath>
+#include <QtMaemo5/QMaemo5InformationBox>
 #endif
 #include <xbmc/xbmcconnection.h>
 
@@ -31,18 +32,25 @@ private slots:
     void grabZoomKeys(bool grab);
     void callEvent(const QDBusObjectPath &, const QString &);
     void callTerminated();
+    void downloadAdded(XbmcDownload* download);
+    void downloadStarted();
+    void downloadDone(bool success);
 #endif
 
     void authenticationRequired(const QString &hostname, const QString &address);
     void connectionChanged(bool connected);
     void hostRemoved();
 
+
 private:
     QmlApplicationViewer *viewer;
     Settings *m_settings;
 
     bool m_videoPaused;
     bool m_audioPaused;
+
+    QMaemo5InformationBox m_infoBox;
+
 };
 
 #endif // MAINWINDOW_H
