@@ -18,6 +18,7 @@
 
 #include "settingsdialog.h"
 
+#include <QScrollArea>
 #include <QGridLayout>
 #include <QDialogButtonBox>
 #include <QStandardItemModel>
@@ -37,8 +38,19 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     setWindowTitle("XbmcRemote - " + tr("Settings"));
 
     QHBoxLayout *hLayout = new QHBoxLayout();
+
+    QScrollArea *scrollArea = new QScrollArea();
+    scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+    scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+
+    QWidget *widget = new QWidget();
+    widget->setMaximumWidth(scrollArea->width());
+
+    hLayout->addWidget(scrollArea);
+
     QVBoxLayout *gridLayout = new QVBoxLayout();
-    hLayout->addLayout(gridLayout);
+    widget->setLayout(gridLayout);
+
 
 #ifdef Q_WS_MAEMO_5
     setLayout(hLayout);
@@ -54,6 +66,10 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     gridLayout->addWidget(m_cbThumbnails, 0, 0);
     m_cbThumbnails->setChecked(settings.useThumbnails());
 
+    m_cbIgnoreArticles = new QCheckBox(tr("Ignore articles for sorting"));
+    gridLayout->addWidget(m_cbIgnoreArticles, 0, 0);
+    m_cbIgnoreArticles->setChecked(settings.ignoreArticle());
+
     m_cbVolume = new QCheckBox(tr("Change volume during calls"));
     gridLayout->addWidget(m_cbVolume, 0, 0);
     m_cbVolume->setChecked(settings.changeVolumeOnCall());
@@ -63,12 +79,20 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     gridLayout->addWidget(m_slVolume, 1, 0);
     m_slVolume->setValue(settings.volumeOnCall());
 
-    m_cbPause = new QCheckBox(tr("Pause video during calls"));
-    gridLayout->addWidget(m_cbPause, 2, 0);
-    m_cbPause->setChecked(settings.pauseOnCall());
+    m_cbPauseVideo = new QCheckBox(tr("Pause video during calls"));
+    gridLayout->addWidget(m_cbPauseVideo, 2, 0);
+    m_cbPauseVideo->setChecked(settings.pauseVideoOnCall());
+
+    m_cbPauseMusic = new QCheckBox(tr("Pause music during calls"));
+    gridLayout->addWidget(m_cbPauseMusic, 2, 0);
+    m_cbPauseMusic->setChecked(settings.pauseMusicOnCall());
 
     connect(m_cbVolume, SIGNAL(clicked(bool)), m_slVolume, SLOT(setEnabled(bool)));
 
+    m_cbShowCallNotification = new QCheckBox(tr("Show call notifications"));
+    gridLayout->addWidget(m_cbShowCallNotification, 2, 0);
+    m_cbShowCallNotification->setChecked(settings.showCallNotifications());
+
 #ifdef Q_WS_MAEMO_5
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, Qt::Vertical);
     hLayout->addWidget(buttonBox);
@@ -77,6 +101,9 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     vLayout->addWidget(buttonBox);
 #endif
 
+    scrollArea->setWidget(widget);
+    scrollArea->setWidgetResizable(true);
+
 
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
@@ -86,8 +113,11 @@ void SettingsDialog::accept()
 {
     Settings settings;
     settings.setUseThumbnails(m_cbThumbnails->isChecked());
+    settings.setIgnoreArticle(m_cbIgnoreArticles->isChecked());
     settings.setChangeVolumeOnCall(m_cbVolume->isChecked());
     settings.setVolumeOnCall(m_slVolume->value());
-    settings.setPauseOnCall(m_cbPause->isChecked());
+    settings.setPauseVideoOnCall(m_cbPauseVideo->isChecked());
+    settings.setPauseMusicOnCall(m_cbPauseMusic->isChecked());
+    settings.setShowCallNotifications(m_cbShowCallNotification->isChecked());
     QDialog::accept();
 }
