@@ -24,14 +24,26 @@
 #include "xbmc.h"
 #include "audioplayer.h"
 #include "playlist.h"
+#include "libraryitem.h"
+#include "xbmcdownload.h"
 
 Albums::Albums(int artistId, XbmcModel *parent) :
     XbmcLibrary(parent),
     m_artistId(artistId)
+{
+    connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
+}
+
+Albums::~Albums()
+{
+    qDebug() << "deleting album model";
+}
+
+void Albums::refresh()
 {
     QVariantMap params;
-    if(artistId != -1) {
-        params.insert("artistid", artistId);
+    if(m_artistId != -1) {
+        params.insert("artistid", m_artistId);
     }
     QVariantList properties;
     properties.append("artist");
@@ -41,14 +53,9 @@ Albums::Albums(int artistId, XbmcModel *parent) :
     QVariantMap sort;
     sort.insert("method", "label");
     sort.insert("order", "ascending");
-    sort.insert("ignorearticle", true);
+    sort.insert("ignorearticle", ignoreArticle());
     params.insert("sort", sort);
     m_requestList.insert(XbmcConnection::sendCommand("AudioLibrary.GetAlbums", params), RequestList);
-    connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
-}
-
-Albums::~Albums()
-{
 }
 
 void Albums::fetchItemDetails(int index)
@@ -82,6 +89,16 @@ void Albums::fetchItemDetails(int index)
     m_detailsRequestMap.insert(id, index);
 }
 
+void Albums::download(int index, const QString &path)
+{
+    qDebug() << "Downloading album";
+    m_downloadPath = path;
+    Songs *downloadModel = new Songs(m_artistId, m_list.at(index)->data(RoleAlbumId).toInt());
+    downloadModel->setDeleteAfterDownload(true);
+    m_downloadList.append(downloadModel);
+    connect(downloadModel, SIGNAL(busyChanged()), SLOT(downloadModelFilled()));
+}
+
 void Albums::responseReceived(int id, const QVariantMap &rsp)
 {
     if(!m_requestList.contains(id)) {
@@ -90,7 +107,6 @@ void Albums::responseReceived(int id, const QVariantMap &rsp)
 
     switch(m_requestList.value(id)) {
     case RequestList: {
-        setBusy(false);
         QList<XbmcModelItem*> list;
         qDebug() << "got albums:" << rsp.value("result");
         QVariantList responseList = rsp.value("result").toMap().value("albums").toList();
@@ -103,13 +119,14 @@ void Albums::responseReceived(int id, const QVariantMap &rsp)
             item->setThumbnail(itemMap.value("thumbnail").toString());
             item->setFileType("directory");
             item->setPlayable(true);
-            item->setIgnoreArticle(true);
+            item->setIgnoreArticle(ignoreArticle());
 
             list.append(item);
         }
         beginInsertRows(QModelIndex(), 0, list.count() - 1);
         m_list = list;
         endInsertRows();
+        setBusy(false);
         }
         break;
     case RequestDetails:
@@ -121,6 +138,21 @@ void Albums::responseReceived(int id, const QVariantMap &rsp)
         item->setGenre(details.value("genre").toString());
         item->setYear(details.value("year").toString());
         emit dataChanged(index(m_detailsRequestMap.value(id), 0, QModelIndex()), index(m_detailsRequestMap.value(id), 0, QModelIndex()));
+        break;
+    }
+}
+
+void Albums::downloadModelFilled()
+{
+    Songs *downloadModel = qobject_cast<Songs*>(sender());
+    qDebug() << "starting batch download of album";
+    for(int i = 0; i < downloadModel->rowCount(); ++i) {
+        downloadModel->download(i, m_downloadPath);
+    }
+
+    m_downloadList.removeAll(downloadModel);
+    if(deleteAfterDownload() && m_downloadList.isEmpty()) {
+        deleteLater();
     }
 }
 
@@ -141,7 +173,6 @@ void Albums::playItem(int index)
 void Albums::addToPlaylist(int index)
 {
     AudioPlaylistItem pItem;
-    pItem.setArtistId(m_artistId);
     pItem.setAlbumId(m_list.at(index)->data(RoleAlbumId).toInt());
     Xbmc::instance()->audioPlayer()->playlist()->addItems(pItem);
 }
