@@ -23,6 +23,8 @@
 
 #include <QStandardItem>
 
+class Songs;
+
 class Albums : public XbmcLibrary
 {
     Q_OBJECT
@@ -30,22 +32,37 @@ public:
     explicit Albums(int artistId = -1, XbmcModel *parent = 0);
     ~Albums();
 
-    int rowCount(const QModelIndex &parent) const;
-    QVariant data(const QModelIndex &index, int role) const;
-
     XbmcModel* enterItem(int index);
     void playItem(int index);
     void addToPlaylist(int index);
 
     QString title() const;
 
+    Q_INVOKABLE void fetchItemDetails(int index);
+    Q_INVOKABLE bool hasDetails() { return true; }
+
+    Q_INVOKABLE virtual void download(int index, const QString &path);
+
+public slots:
+    void refresh();
+
 private slots:
     void responseReceived(int id, const QVariantMap &map);
 
-private:
-    int m_request;
-    int m_artistId;
+    void downloadModelFilled();
 
+private:
+    enum Request {
+        RequestList,
+        RequestDetails
+    };
+
+    QMap<int, Request> m_requestList;
+    QMap<int, int> m_detailsRequestMap;
+
+    int m_artistId;
+    QList<Songs*> m_downloadList;
+    QString m_downloadPath;
 };
 
 #endif // ALBUMS_H
