@@ -23,16 +23,20 @@
 #include "audioplaylistitem.h"
 #include "audioplayer.h"
 #include "playlist.h"
+#include "libraryitem.h"
 
 Artists::Artists(XbmcModel *parent) :
     XbmcLibrary(parent)
 {
     connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
+}
 
+void Artists::refresh()
+{
     QVariantMap params;
 
     QVariantMap sort;
-    sort.insert("ignorearticle", true);
+    sort.insert("ignorearticle", ignoreArticle());
     sort.insert("method", "label");
     params.insert("sort", sort);
 
@@ -40,7 +44,6 @@ Artists::Artists(XbmcModel *parent) :
     properties.append("thumbnail");
     params.insert("properties", properties);
 
-
     m_requestList.insert(XbmcConnection::sendCommand("AudioLibrary.GetArtists", params), RequestList);
 }
 
@@ -76,6 +79,14 @@ void Artists::fetchItemDetails(int index)
     m_detailsRequestMap.insert(id, index);
 }
 
+void Artists::download(int index, const QString &path)
+{
+    qDebug() << "Downloading artist";
+    m_downloadPath = path;
+    Albums *downloadModel = new Albums(m_list.at(index)->data(RoleArtistId).toInt());
+    downloadModel->setDeleteAfterDownload(true);
+    connect(downloadModel, SIGNAL(busyChanged()), SLOT(downloadModelFilled()));
+}
 
 void Artists::responseReceived(int id, const QVariantMap &rsp)
 {
@@ -96,7 +107,7 @@ void Artists::responseReceived(int id, const QVariantMap &rsp)
             item->setFileName("directory");
             item->setArtistId(itemMap.value("artistid").toInt());
             item->setThumbnail(itemMap.value("thumbnail").toString());
-            item->setIgnoreArticle(true);
+            item->setIgnoreArticle(ignoreArticle());
             item->setFileType("directory");
             item->setPlayable(true);
             list.append(item);
@@ -124,6 +135,18 @@ void Artists::responseReceived(int id, const QVariantMap &rsp)
     }
 }
 
+void Artists::downloadModelFilled()
+{
+    Albums *albums = qobject_cast<Albums*>(sender());
+    qDebug() << "starting batch download of artist";
+    for(int i = 0; i < albums->rowCount(); ++i) {
+        albums->download(i, m_downloadPath);
+    }
+    if(deleteAfterDownload()) {
+        deleteLater();
+    }
+}
+
 XbmcModel *Artists::enterItem(int index)
 {
     return new Albums(m_list.at(index)->data(RoleArtistId).toInt(), this);
