@@ -27,17 +27,17 @@ AudioLibrary::AudioLibrary() :
     XbmcLibrary(0)
 {
     setBusy(false);
-    LibraryItem *item = new LibraryItem("Artists");
+    LibraryItem *item = new LibraryItem(tr("Artists"));
     item->setFileType("directory");
     item->setPlayable(false);
     m_list.append(item);
 
-    item = new LibraryItem("Albums");
+    item = new LibraryItem(tr("Albums"));
     item->setFileType("directory");
     item->setPlayable(false);
     m_list.append(item);
 
-    item = new LibraryItem("Titles");
+    item = new LibraryItem(tr("Titles"));
     item->setFileType("directory");
     item->setPlayable(false);
     m_list.append(item);
@@ -69,10 +69,25 @@ void AudioLibrary::addToPlaylist(int index)
 
 QString AudioLibrary::title() const
 {
-    return "Audio Library";
+    return tr("Audio Library");
+}
+
+bool AudioLibrary::allowSearch()
+{
+    return false;
 }
 
 void AudioLibrary::scanForContent()
 {
     XbmcConnection::sendCommand("AudioLibrary.Scan");
 }
+
+void AudioLibrary::clean()
+{
+    XbmcConnection::sendCommand("AudioLibrary.Clean");
+}
+
+void AudioLibrary::refresh()
+{
+    // nothing to do here...
+}
