@@ -22,25 +22,33 @@
 #include "videoplayer.h"
 #include "videoplaylist.h"
 #include "videoplaylistitem.h"
+#include "libraryitem.h"
+#include "xbmcdownload.h"
 
 Episodes::Episodes(int tvshowid, int seasonid, const QString &seasonString, XbmcModel *parent):
     XbmcLibrary(parent),
     m_tvshowid(tvshowid),
     m_seasonid(seasonid),
     m_seasonString(seasonString)
+{
+    connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
+}
+
+void Episodes::refresh()
 {
     QVariantMap params;
-    if(tvshowid != -1) {
-        params.insert("tvshowid", tvshowid);
+    if(m_tvshowid != -1) {
+        params.insert("tvshowid", m_tvshowid);
     }
-    if(seasonid != -1) {
-        params.insert("season", seasonid);
+    if(m_seasonid != -1) {
+        params.insert("season", m_seasonid);
     }
     QVariantList properties;
     properties.append("showtitle");
     properties.append("episode");
     properties.append("thumbnail");
     properties.append("playcount");
+    properties.append("file");
     params.insert("properties", properties);
 
     QVariantMap sort;
@@ -48,7 +56,6 @@ Episodes::Episodes(int tvshowid, int seasonid, const QString &seasonString, Xbmc
     sort.insert("order", "ascending");
     params.insert("sort", sort);
 
-    connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
     m_requestList.insert(XbmcConnection::sendCommand("VideoLibrary.GetEpisodes", params), RequestList);
 }
 
@@ -92,6 +99,21 @@ void Episodes::fetchItemDetails(int index)
     m_detailsRequestMap.insert(id, index);
 }
 
+void Episodes::download(int index, const QString &path)
+{
+    LibraryItem *item = qobject_cast<LibraryItem*>(m_list.at(index));
+
+    QString destination = path + "/Movies/" + item->tvShow() + "/Season " + item->season() + '/';
+    qDebug() << "should download" << destination;
+
+    XbmcDownload *download = new XbmcDownload();
+    download->setDestination(destination);
+    download->setIconId("icon-m-content-videos");
+    download->setLabel(item->title());
+
+    startDownload(index, download);
+}
+
 void Episodes::responseReceived(int id, const QVariantMap &rsp)
 {
     if(!m_requestList.contains(id)) {
@@ -110,10 +132,13 @@ void Episodes::responseReceived(int id, const QVariantMap &rsp)
             item->setTitle(itemMap.value("episode").toString() + ". " + itemMap.value("label").toString());
             //        item->setData(itemMap.value("showtitle").toString() + " - " + itemMap.value("season").toString(), Qt::UserRole+2);
             item->setSubtitle(itemMap.value("showtitle").toString() + " - " + m_seasonString);
+            item->setTvShow(itemMap.value("showtitle").toString());
+            item->setSeason(itemMap.value("season").toInt());
             item->setEpisodeId(itemMap.value("episodeid").toInt());
             item->setThumbnail(itemMap.value("thumbnail").toString());
             item->setPlaycount(itemMap.value("playcount").toInt());
-            item->setIgnoreArticle(false);
+            item->setFileName(itemMap.value("file").toString());
+            item->setIgnoreArticle(false); // We ignore the setting here...
             item->setFileType("file");
             item->setPlayable(true);
             list.append(item);
