@@ -39,6 +39,10 @@ public:
     Q_INVOKABLE void fetchItemDetails(int index);
     Q_INVOKABLE bool hasDetails() { return true; }
 
+    Q_INVOKABLE void download(int index, const QString &path);
+public slots:
+    void refresh();
+
 private slots:
     void responseReceived(int id, const QVariantMap &rsp);
 
