@@ -22,31 +22,38 @@
 #include "videoplayer.h"
 #include "videoplaylist.h"
 #include "videoplaylistitem.h"
+#include "libraryitem.h"
+#include "xbmcdownload.h"
 
 Movies::Movies(XbmcModel *parent) :
     XbmcLibrary(parent)
 {
     connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
 
+}
+
+Movies::~Movies()
+{
+}
+
+void Movies::refresh()
+{
     QVariantMap params;
     QVariantList properties;
     properties.append("fanart");
     properties.append("playcount");
+    properties.append("file");
     params.insert("properties", properties);
 
     QVariantMap sort;
     sort.insert("method", "label");
     sort.insert("order", "ascending");
-    sort.insert("ignorearticle", true);
+    sort.insert("ignorearticle", ignoreArticle());
     params.insert("sort", sort);
 
     m_requestList.insert(XbmcConnection::sendCommand("VideoLibrary.GetMovies", params), RequestList);
 }
 
-Movies::~Movies()
-{
-}
-
 void Movies::fetchItemDetails(int index)
 {
     QVariantMap params;
@@ -95,6 +102,21 @@ void Movies::fetchItemDetails(int index)
     m_detailsRequestMap.insert(id, index);
 }
 
+void Movies::download(int index, const QString &path)
+{
+    LibraryItem *item = qobject_cast<LibraryItem*>(m_list.at(index));
+
+    QString destination = path + "/Movies/";
+    qDebug() << "should download" << destination;
+
+    XbmcDownload *download = new XbmcDownload();
+    download->setDestination(destination);
+    download->setIconId("icon-m-content-videos");
+    download->setLabel(item->title());
+
+    startDownload(index, download);
+}
+
 void Movies::responseReceived(int id, const QVariantMap &rsp)
 {
     if(!m_requestList.contains(id)) {
@@ -114,7 +136,8 @@ void Movies::responseReceived(int id, const QVariantMap &rsp)
             item->setMovieId(itemMap.value("movieid").toInt());
             item->setThumbnail(itemMap.value("fanart").toString());
             item->setPlaycount(itemMap.value("playcount").toInt());
-            item->setIgnoreArticle(true);
+            item->setFileName(itemMap.value("file").toString());
+            item->setIgnoreArticle(ignoreArticle());
             item->setFileType("file");
             item->setPlayable(true);
             list.append(item);
