@@ -35,6 +35,9 @@ public:
 
     QString title() const;
 
+public slots:
+    void refresh();
+
 private slots:
     void responseReceived(int id, const QVariantMap &rsp);
 
