@@ -20,24 +20,29 @@
 #include "files.h"
 #include "xbmcconnection.h"
 #include "xdebug.h"
+#include "libraryitem.h"
 
 Shares::Shares(const QString &mediatype):
     XbmcLibrary(0),
     m_mediaType(mediatype)
+{
+    connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
+}
+
+void Shares::refresh()
 {
     QVariantMap params;
 
 //    QVariant media(mediaString());
-    params.insert("media", mediatype);
+    params.insert("media", m_mediaType);
 
     QVariantMap sort;
     sort.insert("method", "label");
     sort.insert("order", "ascending");
-    sort.insert("ignorearticle", true);
+    sort.insert("ignorearticle", ignoreArticle());
     params.insert("sort", sort);
 
     xDebug(XDAREA_FILES) << "Files.GetShares:" << params;
-    connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
     m_requestId = XbmcConnection::sendCommand("Files.GetSources", params);
 }
 
@@ -57,7 +62,7 @@ void Shares::responseReceived(int id, const QVariantMap &rsp)
         LibraryItem *item = new LibraryItem();
         item->setTitle(itemMap.value("label").toString());
         item->setFileName(itemMap.value("file").toString());
-        item->setIgnoreArticle(true);
+        item->setIgnoreArticle(ignoreArticle());
         item->setFileType("directory");
         list.append(item);
     }
@@ -95,3 +100,8 @@ QString Shares::title() const
     }
     return "";
 }
+
+bool Shares::allowSearch()
+{
+    return false;
+}
