@@ -22,23 +22,37 @@
 #include "audioplaylistitem.h"
 #include "xbmc.h"
 #include "xbmcconnection.h"
+#include "libraryitem.h"
+#include "xbmcdownload.h"
 
 Songs::Songs(int artistid, int albumid, XbmcModel *parent):
     XbmcLibrary(parent),
     m_artistId(artistid),
     m_albumId(albumid)
+{
+    connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
+}
+
+Songs::~Songs()
+{
+    qDebug() << "deleting songs model";
+}
+
+void Songs::refresh()
 {
     QVariantMap params;
-    if(artistid != -1) {
-      params.insert("artistid", artistid);
+    if(m_artistId != -1) {
+      params.insert("artistid", m_artistId);
     }
-    if(albumid != -1) {
-      params.insert("albumid", albumid);
+    if(m_albumId != -1) {
+      params.insert("albumid", m_albumId);
     }
     QVariantList properties;
     properties.append("artist");
     properties.append("album");
     properties.append("thumbnail");
+    properties.append("file");
+
     params.insert("properties", properties);
 
     QVariantMap sort;
@@ -50,7 +64,6 @@ Songs::Songs(int artistid, int albumid, XbmcModel *parent):
     sort.insert("order", "ascending");
     params.insert("sort", sort);
     m_requestList.insert(XbmcConnection::sendCommand("AudioLibrary.GetSongs", params), RequestList);
-    connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
 }
 
 void Songs::fetchItemDetails(int index)
@@ -89,6 +102,21 @@ void Songs::fetchItemDetails(int index)
     m_detailsRequestMap.insert(id, index);
 }
 
+void Songs::download(int index, const QString &path)
+{
+    LibraryItem *item = qobject_cast<LibraryItem*>(m_list.at(index));
+
+    QString destination = path + "/Music/" + item->artist() + '/' + item->album() + '/';
+    qDebug() << "should download" << destination;
+
+    XbmcDownload *download = new XbmcDownload();
+    download->setDestination(destination);
+    download->setIconId("icon-m-content-audio");
+    download->setLabel(item->title());
+
+    startDownload(index, download);
+}
+
 void Songs::responseReceived(int id, const QVariantMap &rsp)
 {
     if(!m_requestList.contains(id)) {
@@ -97,7 +125,6 @@ void Songs::responseReceived(int id, const QVariantMap &rsp)
 
     switch(m_requestList.value(id)) {
     case RequestList: {
-        setBusy(false);
         QList<XbmcModelItem*> list;
     //    qDebug() << "got songs:" << rsp.value("result");
         QVariantList responseList = rsp.value("result").toMap().value("songs").toList();
@@ -106,9 +133,12 @@ void Songs::responseReceived(int id, const QVariantMap &rsp)
             LibraryItem *item = new LibraryItem();
             item->setTitle(itemMap.value("label").toString());
             item->setSubtitle(itemMap.value("artist").toString() + " - " + itemMap.value("album").toString());
+            item->setArtist(itemMap.value("artist").toString());
+            item->setAlbum(itemMap.value("album").toString());
             item->setSongId(itemMap.value("songid").toInt());
             item->setThumbnail(itemMap.value("thumbnail").toString());
-            item->setIgnoreArticle(false);
+            item->setFileName(itemMap.value("file").toString());
+            item->setIgnoreArticle(false); // Ignoring article here...
             item->setFileType("file");
             item->setPlayable(true);
             list.append(item);
@@ -118,6 +148,7 @@ void Songs::responseReceived(int id, const QVariantMap &rsp)
             m_list.append(item);
         }
         endInsertRows();
+        setBusy(false);
         }
         break;
     case RequestDetails:
@@ -126,7 +157,7 @@ void Songs::responseReceived(int id, const QVariantMap &rsp)
         QVariantMap details = rsp.value("result").toMap().value("songdetails").toMap();
         item->setYear(details.value("year").toString());
         item->setRating(details.value("rating").toInt());
-        item->setDuration(details.value("duration").toString());
+        item->setDuration(QTime().addSecs(details.value("duration").toInt()));
         item->setComment(details.value("comment").toString());
         item->setPlaycount(details.value("playcount").toInt());
         emit dataChanged(index(m_detailsRequestMap.value(id), 0, QModelIndex()), index(m_detailsRequestMap.value(id), 0, QModelIndex()));
