@@ -35,8 +35,12 @@ public:
 
     QString title() const;
 
+    bool allowSearch();
+
 public slots:
     void scanForContent();
+    void clean();
+    void refresh();
 
 private:
     enum Request {
