@@ -18,9 +18,11 @@
 
 #include "xbmc.h"
 #include "xbmchostmodel.h"
+#include "xbmcfiltermodel.h"
 #include "xbmcconnection.h"
 #include "xdebug.h"
 #include "xbmcdiscovery.h"
+#include "xbmcdownload.h"
 
 #include "audiolibrary.h"
 #include "artists.h"
@@ -37,6 +39,7 @@
 #include "videoplayer.h"
 #include "pictureplayer.h"
 
+#include "libraryitem.h"
 #include "audioplaylistitem.h"
 #include "videoplaylistitem.h"
 
@@ -82,22 +85,22 @@ Xbmc::Xbmc(QObject *parent) :
     qmlRegisterType<Files>();
     qmlRegisterType<Shares>();
     qmlRegisterType<Keys>();
+    qmlRegisterType<XbmcFilterModel>("Xbmc", 1, 0, "XbmcFilterModel");
 
     qmlRegisterType<AudioPlayer>("Xbmc", 1, 0, "Player");
 
     qmlRegisterType<XbmcHostModel>();
-#if defined Q_WS_MAEMO_5 || defined Q_WS_MAEMO_6
+#if defined Q_WS_MAEMO_5 || defined Q_WS_MAEMO_6 || defined Q_WS_SIMULATOR
     qmlRegisterType<XbmcDiscovery>("Xbmc", 1, 0, "XbmcDiscovery");
 #endif
 
-    QSettings settings("xbmcremote");
-
     m_hosts = new XbmcHostModel(this);
 
     connect(XbmcConnection::notifier(), SIGNAL(connectionChanged()), SLOT(connectionChanged()));
     connect(XbmcConnection::notifier(), SIGNAL(receivedAnnouncement(QVariantMap)), SLOT(parseAnnouncement(QVariantMap)));
     connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
     connect(XbmcConnection::notifier(), SIGNAL(authenticationRequired(QString,QString)), SIGNAL(authenticationRequired(QString, QString)));
+    connect(XbmcConnection::notifier(), SIGNAL(downloadAdded(XbmcDownload*)), SLOT(slotDownloadAdded(XbmcDownload*)));
 
     m_audioPlayer = new AudioPlayer(this);
     m_videoPlayer = new VideoPlayer(this);
@@ -137,6 +140,24 @@ void Xbmc::init()
     params.insert("properties", list);
     id = XbmcConnection::sendCommand("System.GetProperties", params);
     m_requestMap.insert(id, RequestSystemProperties);
+
+    queryActivePlayers();
+}
+
+void Xbmc::slotDownloadAdded(XbmcDownload *download)
+{
+    connect(download, SIGNAL(finished(bool)), SLOT(downloadFinished(bool)));
+    emit downloadAdded(download);
+}
+
+void Xbmc::downloadFinished(bool success)
+{
+    XbmcDownload *download = qobject_cast<XbmcDownload*>(sender());
+    if(success) {
+        emit displayNotification(tr("Finished downloading %1").arg(download->label()));
+    } else {
+        emit displayNotification(tr("Error downloading %1").arg(download->label()));
+    }
 }
 
 bool Xbmc::connected()
@@ -149,6 +170,14 @@ XbmcHost *Xbmc::connectedHost()
     return XbmcConnection::connectedHost();
 }
 
+QString Xbmc::connectedHostName()
+{
+    if(XbmcConnection::connected()) {
+        return XbmcConnection::connectedHost()->hostname();
+    }
+    return QString();
+}
+
 void Xbmc::setAuthCredentials(const QString &username, const QString &password)
 {
     XbmcConnection::setAuthCredentials(username, password);
@@ -202,7 +231,13 @@ Player *Xbmc::activePlayer()
 
 void Xbmc::parseAnnouncement(const QVariantMap &map)
 {
-    Q_UNUSED(map)
+    if(map.value("method").toString() == "Player.OnPlay") {
+        QVariantMap data= map.value("params").toMap().value("data").toMap();
+        qDebug() << "************************************************" << data.value("player").toMap().value("playerid") << m_activePlayer->playerId();
+//        if(data.value("player").toMap().value("playerid").toInt() != m_activePlayer->playerId()) {
+            queryActivePlayers();
+//        }
+    }
 }
 
 void Xbmc::responseReceived(int id, const QVariantMap &response)
@@ -289,6 +324,11 @@ Keys *Xbmc::keys()
     return m_keys;
 }
 
+bool Xbmc::connecting()
+{
+    return XbmcConnection::connecting();
+}
+
 void Xbmc::connectionChanged()
 {
     if(connected()) {
@@ -306,9 +346,19 @@ void Xbmc::setVolume(int volume)
         volume = 100;
     }
 
-    if(XbmcConnection::connectedHost() && !XbmcConnection::connectedHost()->volumeUpCommand().isEmpty()) {
-        QProcess p;
-        p.execute(XbmcConnection::connectedHost()->volumeUpCommand(), QStringList() << QString::number(volume));
+    if(XbmcConnection::connectedHost() && !XbmcConnection::connectedHost()->volumeUpCommand().isEmpty() && !XbmcConnection::connectedHost()->volumeUpCommand().isEmpty()) {
+        QString cmd;
+        QStringList args;
+        if(volume < m_volume) {
+            args = XbmcConnection::connectedHost()->volumeDownCommand().split(" ");
+            cmd = args.takeFirst();
+        } else {
+            args = XbmcConnection::connectedHost()->volumeUpCommand().split(" ");
+            cmd = args.takeFirst();
+        }
+        args << QString::number(volume);
+        qDebug() << "executing command:" << cmd << args << QProcess::execute(cmd, args);
+
     } else {
         if(volume != m_volume) {
             QVariantMap map;
@@ -364,7 +414,7 @@ void Xbmc::restoreVolume()
     m_volumeAnimation.start();
 }
 
-void Xbmc::showNotification(const QString &header, const QString &text)
+void Xbmc::sendNotification(const QString &header, const QString &text)
 {
     XbmcConnection::sendLegacyCommand("ExecBuiltIn(Notification(" + header + ", " + text + ",5000,DefaultIconInfo.png))");
 }
