@@ -37,11 +37,15 @@ class Shares;
 
 class Keys;
 
+class XbmcDownload;
+
 class Xbmc : public QObject
 {
     Q_OBJECT
+    Q_PROPERTY(bool connecting READ connecting NOTIFY connectingChanged)
     Q_PROPERTY(bool connected READ connected NOTIFY connectedChanged)
     Q_PROPERTY(QString connectionError READ connectionError NOTIFY connectedChanged)
+    Q_PROPERTY(QString connectedHostName READ connectedHostName NOTIFY connectedChanged)
     Q_PROPERTY(QString vfsPath READ vfsPath NOTIFY vfsPathChanged)
     Q_PROPERTY(Player* activePlayer READ activePlayer NOTIFY activePlayerChanged)
     Q_PROPERTY(bool picturePlayerActive READ picturePlayerActive NOTIFY picturePlayerActiveChanged)
@@ -70,8 +74,10 @@ public:
 
     Q_INVOKABLE Keys *keys();
 
+    bool connecting();
     bool connected();
     XbmcHost *connectedHost();
+    QString connectedHostName();
     QString connectionError();
     Q_INVOKABLE XbmcHostModel* hostModel();
     Q_INVOKABLE void setAuthCredentials(const QString &username, const QString &password);
@@ -86,6 +92,9 @@ public:
     Q_INVOKABLE void dimVolumeTo(int newVolume);
     Q_INVOKABLE void restoreVolume();
 
+    Q_INVOKABLE void sendNotification(const QString &header, const QString &text);
+
+
     bool canShutdown();
     bool canReboot();
     bool canHibernate();
@@ -100,8 +109,9 @@ public slots:
     void queryActivePlayers();
 
 signals:
-    void authenticationRequired(const QString &hostname, const QString &address);
+    void connectingChanged();
     void connectedChanged(bool connected);
+    void authenticationRequired(const QString &hostname, const QString &address);
     void activePlayerChanged();
     void volumeChanged(int volume);
     void vfsPathChanged();
@@ -111,11 +121,17 @@ signals:
 
     void systemPropertiesChanged();
 
+    void downloadAdded(XbmcDownload* download);
+
+    void displayNotification(const QString &text);
+
 private slots:
     void parseAnnouncement(const QVariantMap &map);
     void responseReceived(int id, const QVariantMap &rsp);
     void connectionChanged();
     void init();
+    void slotDownloadAdded(XbmcDownload *download);
+    void downloadFinished(bool success);
 
 private:
     static Xbmc *s_instance;
