@@ -20,6 +20,7 @@
 #include "xbmcconnection_p.h"
 
 #include "xdebug.h"
+#include "xbmcdownload.h"
 
 #include <qjson/parser.h>
 #include <qjson/serializer.h>
@@ -30,6 +31,7 @@
 #include <QNetworkReply>
 #include <QAuthenticator>
 #include <QHostInfo>
+#include <QDir>
 
 #define DEBUGJSON
 
@@ -40,6 +42,11 @@ void connect(XbmcHost *host)
     instance()->connect(host);
 }
 
+bool connecting()
+{
+    return instance()->connecting();
+}
+
 XbmcHost *connectedHost()
 {
     return instance()->connectedHost();
@@ -85,6 +92,11 @@ int xbmcVersion()
     return instance()->xbmcVersion();
 }
 
+void download(XbmcDownload *download)
+{
+    instance()->download(download);
+}
+
 /*****************************************************************
   Private impl
   ***************************************************************/
@@ -94,6 +106,7 @@ XbmcConnectionPrivate::XbmcConnectionPrivate(QObject *parent) :
     m_commandId(0),
     m_versionRequestId(-1),
     m_host(0),
+    m_connecting(false),
     m_connected(false)
 {
     m_socket = new QTcpSocket();
@@ -119,7 +132,17 @@ XbmcConnectionPrivate::XbmcConnectionPrivate(QObject *parent) :
 
 void XbmcConnectionPrivate::connect(XbmcHost *host)
 {
+    if(host != 0) {
+        m_host = host;
+    }
+    if(m_host == 0) {
+        qDebug() << "No host given and no previously connected host stored. Cannot connect.";
+        return;
+    }
+
     qDebug() << "connecting";
+    m_connecting = true;
+
     // Stop the reconnect timer in case someone else triggers the connect
     m_reconnectTimer.stop();
 
@@ -131,11 +154,8 @@ void XbmcConnectionPrivate::connect(XbmcHost *host)
         m_socket->abort();
     }
 
-    if(host != 0) {
-        m_host = host;
-    }
 
-    xDebug(XDAREA_CONNECTION) << "connecting to" << m_host->hostname() << m_host->address() << m_host->username() << m_host->password();
+    xDebug(XDAREA_CONNECTION) << "connecting to" << m_host->hostname() << m_host->address() << m_host->username() << "(using password:" << !m_host->password().isEmpty() << ")";
     // We connect to telnet on port 9090 for the announcements
     m_socket->connectToHost(m_host->address(), 9090);
 
@@ -148,6 +168,12 @@ XbmcHost* XbmcConnectionPrivate::connectedHost()
     return m_host;
 }
 
+bool XbmcConnectionPrivate::connecting()
+{
+    xDebug(XDAREA_CONNECTION) << "current socket state" << m_socket->state();
+    return m_connecting;
+}
+
 void XbmcConnectionPrivate::slotConnected()
 {
     xDebug(XDAREA_CONNECTION) << "Connected to remote host. Asking for version...";
@@ -164,6 +190,7 @@ void XbmcConnectionPrivate::slotDisconnected()
         xDebug(XDAREA_CONNECTION) << "No connection yet, cannot disconnect.";
     }
     xDebug(XDAREA_CONNECTION) << "Disconnected";
+    m_connecting = false;
     m_connected = false;
     m_connectionError = tr("The connection has been disconnected");
     emit m_notifier->connectionChanged();
@@ -193,6 +220,7 @@ void XbmcConnectionPrivate::sendNextCommand2() {
 
         QNetworkRequest request;
         request.setUrl(QUrl("http://" + m_host->address() + ":" + QString::number(m_host->port()) + "/jsonrpc"));
+        request.setHeader(QNetworkRequest::ContentTypeHeader, "application/json");
 
         QVariantMap map;
         map.insert("jsonrpc", "2.0");
@@ -221,9 +249,9 @@ void XbmcConnectionPrivate::sendNextCommand2() {
 
 void XbmcConnectionPrivate::replyReceived()
 {
-    QNetworkReply *reply = static_cast<QNetworkReply*>(sender());
-    QString commands = reply->readAll();
+    QNetworkReply *reply = static_cast<QNetworkReply*>(sender()); // We know its working... so don't waste time with typesafe casts
     reply->deleteLater();
+    QString commands = reply->readAll();
 
     if(reply->error() != QNetworkReply::NoError) {
         m_socket->disconnectFromHost();
@@ -277,6 +305,7 @@ void XbmcConnectionPrivate::replyReceived()
                 m_connected = true;
                 m_connectionError.clear();
             }
+            m_connecting = false;
             emit m_notifier->connectionChanged();
             continue;
         }
@@ -447,6 +476,124 @@ Notifier *XbmcConnectionPrivate::notifier()
     return m_notifier;
 }
 
+void XbmcConnectionPrivate::download(XbmcDownload *download)
+{
+    qDebug() << "added download:" << download->source() << "-->" << download->destination();
+    m_downloadQueue.append(download);
+    emit m_notifier->downloadAdded(download);
+    downloadNext();
+}
+
+void XbmcConnectionPrivate::downloadNext()
+{
+    if(!m_activeDownloadsMap.isEmpty()) {
+        qDebug() << "Download in progress... not starting next one";
+        return;
+    }
+    if(m_downloadQueue.isEmpty()) {
+        qDebug() << "Download queue empty";
+        return;
+    }
+    XbmcDownload *download = m_downloadQueue.takeFirst();
+    qDebug() << "Starting download:" << download->source() << "-->" << download->destination();
+    QByteArray url = QUrl::toPercentEncoding("http://" + XbmcConnection::connectedHost()->address() + ':' + QString::number(XbmcConnection::connectedHost()->port()) + '/');
+    url.append(download->source());
+    QNetworkRequest request;
+    request.setUrl(QUrl::fromPercentEncoding(url));
+    qDebug() << "getting:" << request.url();
+
+    QFile *file = new QFile(download->destination());
+    QFileInfo fi(download->destination());
+
+    if(!fi.dir().exists()) {
+        if(!fi.dir().mkpath(fi.dir().absolutePath())) {
+            qDebug() << "cannot create dir" << fi.dir().absolutePath();
+            download->setFinished(false);
+            download->deleteLater();
+            delete file;
+            return;
+        }
+    }
+    if(!file->open(QIODevice::ReadWrite)) {
+        qDebug() << "cannot open destination" << download->destination();
+        download->setFinished(false);
+        download->deleteLater();
+        delete file;
+        return;
+    }
+
+    QNetworkReply *reply = m_network->get(request);
+    QObject::connect(reply, SIGNAL(readyRead()), SLOT(downloadReadyRead()));
+    QObject::connect(reply, SIGNAL(downloadProgress(qint64,qint64)), SLOT(downloadProgress(qint64,qint64)));
+    QObject::connect(reply, SIGNAL(finished()), SLOT(downloadFinished()));
+    QObject::connect(download, SIGNAL(cancelled()), SLOT(cancelDownload()));
+    qDebug() << reply->errorString();
+
+    download->setFile(file);
+    download->setStarted();
+    m_activeDownloadsMap.insert(reply,download);
+}
+
+void XbmcConnectionPrivate::downloadReadyRead()
+{
+    QNetworkReply *reply = static_cast<QNetworkReply*>(sender());
+    XbmcDownload *download = m_activeDownloadsMap.value(reply);
+    QFile *file = download->file();
+    if(file->write(reply->readAll()) == -1) {
+        reply->abort();
+        reply->deleteLater();
+        download->setFinished(false);
+        download->deleteLater();
+        file->remove(); // Try to delete the broken file
+        delete file;
+    }
+}
+
+void XbmcConnectionPrivate::downloadProgress(qint64 progress, qint64 total)
+{
+    QNetworkReply *reply = static_cast<QNetworkReply*>(sender());
+    XbmcDownload *download = m_activeDownloadsMap.value(reply);
+//    qDebug() << "updating progress:" << progress << "/" << total;
+    download->setTotal(total);
+    download->setProgress(progress);
+}
+
+void XbmcConnectionPrivate::cancelDownload()
+{
+    XbmcDownload *download = static_cast<XbmcDownload*>(sender());
+    QNetworkReply *reply = m_activeDownloadsMap.key(download);
+    if(reply) {
+        reply->close();
+    }
+}
+
+void XbmcConnectionPrivate::downloadFinished()
+{
+    QNetworkReply *reply = static_cast<QNetworkReply*>(sender());
+    XbmcDownload *download = m_activeDownloadsMap.value(reply);
+
+    QFile *file = download->file();
+    download->setFile(0);
+
+    file->write(reply->readAll());
+    file->close();
+    delete file;
+
+    if(reply->error() == QNetworkReply::NoError) {
+        qDebug() << "download finished";
+        download->setFinished(true);
+    } else {
+        qDebug() << "download failed" << reply->error() << reply->errorString();
+        download->setFinished(false);
+    }
+    download->deleteLater();
+
+    m_activeDownloadsMap.remove(reply);
+    reply->deleteLater();
+
+    downloadNext();
+}
+
 bool XbmcConnectionPrivate::connected()
 {
     return m_connected;
