@@ -24,11 +24,13 @@
 #include <QNetworkAccessManager>
 
 class XbmcHost;
+class XbmcDownload;
 
 namespace XbmcConnection
 {
 
 void connect(XbmcHost *host);
+bool connecting();
 XbmcHost *connectedHost();
 void setAuthCredentials(const QString &username, const QString &password);
 
@@ -41,6 +43,8 @@ void sendLegacyCommand(const QString &command);
 
 QNetworkAccessManager *nam();
 
+void download(XbmcDownload *download);
+
 class Notifier: public QObject
 {
     Q_OBJECT
@@ -51,6 +55,7 @@ signals:
     void receivedAnnouncement(const QVariantMap &announcement);
     void responseReceived(int id, const QVariantMap &response);
     void authenticationRequired(const QString &hostname, const QString &address);
+    void downloadAdded(XbmcDownload *download);
 };
 Notifier *notifier();
 }
