@@ -29,6 +29,9 @@
 #include <QTimer>
 #include <QNetworkAccessManager>
 #include <QDate>
+#include <QFile>
+
+class XbmcDownload;
 
 namespace XbmcConnection
 {
@@ -58,8 +61,8 @@ class XbmcConnectionPrivate : public QObject
 public:
     explicit XbmcConnectionPrivate(QObject *parent = 0);
 
-    void connect(XbmcHost *host);
     XbmcHost *connectedHost();
+    bool connecting();
     bool connected();
     QString connectionError();
     void setAuthCredentials(const QString &username, const QString &password);
@@ -67,10 +70,16 @@ public:
     int xbmcVersion();
 
     int sendCommand(const QString &command, const QVariant &parms = QVariant());
+    void sendLegacyCommand(const QString &command);
 
     QNetworkAccessManager *nam();
     Notifier *notifier();
 
+    void download(XbmcDownload *download);
+
+public slots:
+    void connect(XbmcHost *host = 0);
+
 private slots:
     void readData();
     void clearPending();
@@ -80,6 +89,14 @@ private slots:
 
     void replyReceived();
     void authenticationRequired(QNetworkReply *reply, QAuthenticator *authenticator);
+
+    void downloadNext();
+    void downloadReadyRead();
+    void downloadFinished();
+    void downloadProgress(qint64 progress, qint64 total);
+
+    void cancelDownload();
+
 private:
     QTcpSocket *m_socket;
     int m_commandId;
@@ -90,6 +107,7 @@ private:
     QList<Command> m_commandQueue;
     Command m_currentPendingCommand;
     QTimer m_timeoutTimer;
+    QTimer m_reconnectTimer;
 
     void sendNextCommand();
     void sendNextCommand2();
@@ -98,9 +116,13 @@ private:
 
     QNetworkAccessManager *m_network;
     QNetworkReply *m_lastAuthRequest;
+    bool m_connecting;
     bool m_connected;
     QString m_connectionError;
 
+    QList<XbmcDownload*> m_downloadQueue;
+    QMap<QNetworkReply*, XbmcDownload*> m_activeDownloadsMap;
+
 };
 Q_GLOBAL_STATIC(XbmcConnectionPrivate, instance)
 
